@@ -44,6 +44,7 @@ struct nft_ctx;
 #define PORT_GTP1_U 2152
 
 extern struct osmo_tdef_group g_upf_tdef_groups[];
+extern struct osmo_tdef g_upf_nft_tdefs[];
 
 struct pfcp_vty_cfg {
 	char *local_addr;
@@ -117,6 +118,7 @@ struct g_upf {
 
 	struct {
 		uint32_t next_local_teid_state;
+		uint16_t next_echo_seq_nr;
 	} gtp;
 
 	struct llist_head netinst;
